@@ -89,28 +89,36 @@ class hora:
       :return: la fecha actual
       :rtype: string
       """
+      now = datetime.now().strftime("%Y-%m-%d")
       if(asString):
-         return datetime.now().strftime("%Y-%m-%d")
+         return now
       else:
-         return self.get(False) - dateutil.relativedelta.relativedelta(days=1)
+         return datetime.strptime(now,"%Y-%m-%d")
 
-   def ayer(self):
+   def ayer(self,asString=True):
       """
       :return: la fecha de ayer
       :rtype: string
       """
-      today = datetime.today()
-      yesterday = today - timedelta(days=1)
-      return yesterday.strftime("%Y-%m-%d")
+      yesterday = datetime.now() - timedelta(days=1)
+      yesterday = yesterday.strftime("%Y-%m-%d")
+      if(asString):
+         return yesterday
+      else:
+         return datetime.strptime(yesterday,"%Y-%m-%d")
 
-   def diasAtras(self,dias):
+
+   def diasAtras(self,dias,asString=True):
       """
       :return: la fecha de ayer
       :rtype: string
       """
-      today = datetime.today()
-      yesterday = today - timedelta(days=dias)
-      return yesterday.strftime("%Y-%m-%d")
+      yesterday = datetime.now() - timedelta(days=dias)
+      yesterday = yesterday.strftime("%Y-%m-%d")
+      if(asString):
+         return yesterday
+      else:
+         return datetime.strptime(yesterday,"%Y-%m-%d")
 
 hora=hora()
 
